oceantide package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   oceantide.core
   oceantide.input
   oceantide.output

Submodules
----------

oceantide.cli module
--------------------

.. automodule:: oceantide.cli
   :members:
   :undoc-members:
   :show-inheritance:

oceantide.constituents module
-----------------------------

.. automodule:: oceantide.constituents
   :members:
   :undoc-members:
   :show-inheritance:

oceantide.ellipse module
------------------------

.. automodule:: oceantide.ellipse
   :members:
   :undoc-members:
   :show-inheritance:

oceantide.tide module
---------------------

.. automodule:: oceantide.tide
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: oceantide
   :members:
   :undoc-members:
   :show-inheritance:
